pub enum Error<E> {
LimitExceeded(usize),
Serde(E),
}Expand description
An error returned by deserialize.
Variants
LimitExceeded(usize)
The value did not fit into the operation budget.
Serde(E)
The payload could not be deserialized.
Implementations
Sourceimpl<E> Error<E>
impl<E> Error<E>
Sourcepub fn is_limit_exceeded(&self) -> bool
pub fn is_limit_exceeded(&self) -> bool
Returns true if deserialization failed because it ran out of budget.
Sourcepub fn into_serde(self) -> Option<E>
pub fn into_serde(self) -> Option<E>
Returns the contained deserialization error, if the budget was not exceeded.